:mod:`~arcs.gsi.slcs` -- utility functions for assisting with responses from SLCS servers
========================================================================

.. _ref-slcs

.. module:: arcs.gsi.slcs
.. moduleauthor:: Russell Sim <russell@vpac.org>

.. autofunction:: parse_req_response

.. autofunction:: parse_cert_response

.. autofunction:: slcs_handler

